package com.jiuqi.monitor;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import com.jiuqi.monitor.IProgressMonitor;
import com.jiuqi.monitor.ProgressTask;
import java.util.Stack;

public abstract class AbstractProgressMonitor implements IProgressMonitor {
  private volatile boolean canceled;
  
  private volatile double position;
  
  private Stack tasks = new Stack();
  
  private static final double POS_DELTA = 1.0E-4D;
  
  public void cancel() {
    this.canceled = true;
  }
  
  public void finishTask() {
    if (this.tasks.isEmpty())
      return; 
    this.tasks.pop();
    if (this.tasks.isEmpty()) {
      this.position = 1.0D;
      notify(this.position);
    } 
  }
  
  public double getPosition() {
    return this.position;
  }
  
  public boolean isCanceled() {
    return this.canceled;
  }
  
  public abstract void prompt(String paramString);
  
  public void startTask(String taskName, int stepCount) {
    ProgressTask curTask = this.tasks.isEmpty() ? null : this.tasks.peek();
    curTask = new ProgressTask(curTask, taskName, stepCount);
    this.tasks.push(curTask);
  }
  
  public void startTask(String taskName, int[] steps) {
    ProgressTask curTask = this.tasks.isEmpty() ? null : this.tasks.peek();
    curTask = new ProgressTask(curTask, taskName, steps);
    this.tasks.push(curTask);
  }
  
  protected abstract void notify(double paramDouble);
  
  public void stepIn() {
    if (this.tasks.empty())
      return; 
    ProgressTask curTask = this.tasks.peek();
    curTask.stepIn();
    double pos = curTask.position();
    if (pos > this.position) {
      if (pos - this.position > 1.0E-4D)
        notify(pos); 
      this.position = pos;
    } 
  }
  
  public String getCurrentTask() {
    return this.tasks.isEmpty() ? null : ((ProgressTask)this.tasks.peek()).name();
  }
  
  public int getCurrentLevel() {
    return this.tasks.size();
  }
}
